<?php

/**
 * Hook into admin order data, after shipping table, to:
 * - include a fraud prevention warning if shipping doesn't match billing.
 * - include custom meta like delivery time window and gift recipient.
 */
add_action( 'woocommerce_admin_order_data_after_shipping_address', 'bt_order_shipping_custom', 5 );
function bt_order_shipping_custom( $order ) {

	// things to do for sellers
	if ( bt_use_sellers() ) {

		// get the order to work with
		if ( is_int( $order ) ) {
			$order_id = $order;
			$order = new \WC_Order( $order_id );
		} else if ( is_a( $order, '\WC_Order' ) ) {
			$order_id = $order->get_id();
		} else {
			// unhandled argument case
			\App\bt_email_alert(
				'Error running bt_order_shipping_custom()',
				'The argument $order provided is not an integer or object. It is: ' . print_r( $order, 1 )
			);

			return false;
		}

		if ( $order->get_total() > 100 && ! bt_order_shipping_matches_billing( $order ) ) {
			echo '<div class="alert alert-warning">' . bt_shipping_fraud_prevention_message() . '</div>';
		}

		if ( $time_windows = bt_ecomm_option( 'checkout_time_window_options' ) ) {
			if ( ! $time_window_label = bt_ecomm_option( 'checkout_time_window_label' ) ) {
				$time_window_label = 'Time Window';
			}

			if ( $selected_window = get_post_meta( $order_id, 'time_window', true ) ) {
				echo '<div class="alert alert-info">' . $time_window_label . ': <strong>' . $selected_window . '</strong></div>';
			}
		}
	}

	if ( $is_a_gift = bt_ecomm_option( 'checkout_is_a_gift' ) ) {
		echo bt_order_gift_recipient_html( $order->get_id() );
	}
}


/**
 * Hook into order details after table, to:
 * - include time window info
 * - include gift recipient info
 */
add_action( 'woocommerce_order_details_after_order_table', function( $order ) {
	if ( $time_windows = bt_ecomm_option( 'checkout_time_window_options' ) ) {
		if ( ! $time_window_label = bt_ecomm_option( 'checkout_time_window_label' ) ) {
			$time_window_label = 'Time Window';
		}

		if ( $selected_window = get_post_meta( $order->id, 'time_window', true ) ) {
			echo '<p class="text-center">' . $time_window_label . ': <strong>' . $selected_window . '</strong></p>';
		}
	}

	if ( $is_a_gift = bt_ecomm_option( 'checkout_is_a_gift' ) ) {
		echo bt_order_gift_recipient_html( $order->get_id() );
	}
} );


/**
 * Hook into Woo Order Export default settings, to:
 * - include billing phone
 */
add_filter( 'woe_before_apply_default_settings', function ( $settings, $mode ) {
	//error_log( __METHOD__ . ' -- settings = ' . print_r( $settings, true ) );
	//error_log( __METHOD__ . ' -- mode = ' . print_r( $mode, true ) );

	$settings['order_fields'][] = [
		'segment' => 'billing',
		'key' => 'billing_phone',
		'label' => 'Phone',
		'format' => 'string',
		'colname' => 'Phone',
	];

	return $settings;
}, 2, 9988 );


/**
 * Helper to see if an order is virtual (contains only virtual items).
 *
 * @param int|\WC_Order $order
 *
 * @return bool
 */
function bt_is_order_virtual( $order ) {
	$is_virtual = false;

	if ( ! $order ) {
		return $is_virtual;
	}

	$order = wc_get_order( $order );

	if ( count( $order->get_items() ) > 0 ) {
		foreach ( $order->get_items() as $item ) {
			if ( 'line_item' == $item['type'] ) {
				$product = $item->get_product();
				if ( ! $product->is_virtual() ) {
					// once we find one non-virtual product, break out of the loop
					$is_virtual = false;
					break;
				} else {
					//error_log( __METHOD__ . ' -- item ' . $item->get_name() . ' IS VIRTUAL' );
					$is_virtual = true;
				}
			}
		}
	}

	return $is_virtual;
}


/**
 * Helper to see if an order used the specified gateway.
 *
 * @param int|\WC_Order $order
 * @param string $gateway
 *
 * @return bool
 */
function bt_is_order_gateway( $order, $gateway ) {
	//error_log( __METHOD__ . ' -- checking for gateway ' . $gateway );
	$gateway_match = false;

	if ( ! $order || empty( $gateway ) ) {
		return $gateway_match;
	}

	$order = wc_get_order( $order );

	return strtolower( $order->get_payment_method() ) == strtolower( $gateway );
}
